WebViewController class

Inheritance

Constructors

WebViewController(MethodChannel _pluginChannel, int _index, {Widget? loading})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
javascriptChannels → Map<String, JavascriptChannel>
no setter
listener → WebviewEventsListener?
no setter
loadingWidget → Widget
no setter
onCursorChanged → dynamic
no setter
onFocusedNodeChangeMessage → dynamic
no setter
onImeCompositionRangeChangedMessage → dynamic
no setter
onJavascriptChannelMessage → dynamic
no setter
onToolTip → dynamic
no setter
ready → Future<void>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ bool
The current value stored in this notifier.
getter/setter pairinherited
webviewWidget → Widget
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → Future<void>
Discards any resources used by the object.
override
evaluateJavascript(String code) → Future
executeJavaScript(String code) → Future<void>
goBack() → Future<void>
goForward() → Future<void>
imeCommitText(String composingText) → Future<void>
imeSetComposition(String composingText) → Future<void>
initialize(String url) → Future<void>
Initializes the underlying platform view.
loadUrl(String url) → Future<void>
Loads the given url.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openDevTools() → Future<void>
reload() → Future<void>
Reloads the current document.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
sendJavaScriptChannelCallBack(bool error, String result, String callbackId, String frameId) → Future<void>
setClientFocus(bool focus) → Future<void>
setJavaScriptChannels(Set<JavascriptChannel> channels) → Future<void>
setWebviewListener(WebviewEventsListener listener) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited