WebviewManager class

Inheritance

Constructors

WebviewManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
nextIndex ↔ int
getter/setter pair
pluginChannel → MethodChannel
final
ready → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ bool
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
createWebView({Widget? loading, InjectUserScripts? injectUserScripts}) → WebViewController
deleteCookie(String domain, String key) → Future<void>
dispose() → Future<void>
Discards any resources used by the object.
override
initialize({String? userAgent}) → Future<void>
methodCallhandler(MethodCall call) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onBrowserCreated(int browserIndex, int browserId) → void
quit() → Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWebView(int browserId) → void
setCookie(String domain, String key, String val) → Future<void>
toString() → String
A string representation of this object.
inherited
visitAllCookies() → Future
visitUrlCookies(String domain, bool isHttpOnly) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited